@@ -272,6 +272,8 @@ adsl <- adsl %>%
     dataset_add = ex,
     by_vars = exprs(STUDYID, USUBJID),
     new_var = SAFFL,
+    false_value = "N",
+    missing_value = "N",
     condition = (EXDOSE > 0 | (EXDOSE == 0 & str_detect(EXTRT, "PLACEBO")))
   ) %>%
   ## Groupings and others variables ----
