@@ -170,14 +170,16 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
   )
 })
 
-## Test 3: no new observations for subjects not in ADSL ----
-test_that("derive_param_tte Test 3: no new observations for subjects not in ADSL", {
+## Test 3: no records for subjects not in ADSL, multiple events/cens ----
+test_that("derive_param_tte Test 3: no records for subjects not in ADSL, multiple events/cens", {
+  # For subject 01 both events are at the same date, for subject 04 both censorings
+  # are at the same date
   adsl <- tibble::tribble(
     ~USUBJID, ~DTHFL, ~DTHDT,            ~RSPDT,
-    "01",     "Y",    ymd("2021-06-12"), ymd("2021-03-04"),
+    "01",     "Y",    ymd("2021-05-05"), ymd("2021-03-04"),
     "02",     "N",    NA,                NA,
     "03",     "Y",    ymd("2021-08-21"), NA,
-    "04",     "N",    NA,                ymd("2021-04-14"),
+    "04",     "N",    NA,                ymd("2021-05-15"),
     "05",     "N",    NA,                NA
   ) %>%
     mutate(STUDYID = "AB42")
@@ -189,7 +191,7 @@ test_that("derive_param_tte Test 3: no new observations for subjects not in ADSL
     "01",     "PD",   ymd("2021-05-05"), 3,
     "02",     "PD",   ymd("2021-02-03"), 1,
     "04",     "SD",   ymd("2021-02-13"), 1,
-    "04",     "PR",   ymd("2021-04-14"), 2,
+    "04",     "SD",   ymd("2021-04-14"), 2,
     "04",     "CR",   ymd("2021-05-15"), 3
   ) %>%
     mutate(STUDYID = "AB42", PARAMCD = "OVR")
@@ -259,7 +261,7 @@ test_that("derive_param_tte Test 3: no new observations for subjects not in ADSL
     dataset_adsl = filter(adsl, !is.na(RSPDT)),
     start_date = RSPDT,
     event_conditions = list(pd, death),
-    censor_conditions = list(lastvisit, first_response),
+    censor_conditions = list(first_response, lastvisit),
     source_datasets = list(adsl = adsl, adrs = adrs),
     set_values_to = exprs(
       PARAMCD = "DURRSP",
@@ -885,18 +887,246 @@ test_that("derive_param_tte Test 12: test dataset and dynamic byvars populated",
   )
 })
 
+## Test 13: error if dataset_name not in source_datsets ----
+test_that("derive_param_tte Test 13: error if dataset_name not in source_datsets", {
+  adsl <- tibble::tribble(
+    ~USUBJID, ~DTHFL, ~DTHDT,            ~LSTALVDT,         ~TRTSDT,           ~TRTSDTF,
+    "03",     "Y",    ymd("2021-08-21"), ymd("2021-08-21"), ymd("2021-08-10"), NA,
+    "04",     "N",    NA,                ymd("2021-05-24"), ymd("2021-02-03"), NA
+  ) %>%
+    mutate(STUDYID = "AB42")
+
+  death <- event_source(
+    dataset_name = "adsl",
+    filter = DTHFL == "Y",
+    date = DTHDT,
+    set_values_to = exprs(
+      EVENTDESC = "DEATH",
+      SRCDOM = "ADSL",
+      SRCVAR = "DTHDT"
+    )
+  )
+
+  lstalv <- censor_source(
+    dataset_name = "adls",
+    date = LSTALVDT,
+    censor = 1,
+    set_values_to = exprs(
+      EVENTDESC = "LAST KNOWN ALIVE DATE",
+      SRCDOM = "ADSL",
+      SRCVAR = "LSTALVDT"
+    )
+  )
+
+  expect_snapshot(
+    derive_param_tte(
+      dataset_adsl = adsl,
+      start_date = TRTSDT,
+      event_conditions = list(death),
+      censor_conditions = list(lstalv),
+      source_datasets = list(adsl = adsl),
+      set_values_to = exprs(
+        PARAMCD = "OS",
+        PARAM = "Overall Survival"
+      )
+    ),
+    error = TRUE
+  )
+})
+
+## Test 14: detects duplicates in input datasets via pipeline functions ----
+test_that("derive_param_tte Test 14: detects duplicates in input datasets via pipeline functions", {
+  # Define ADSL dataset
+  adsl <- tibble::tribble(
+    ~USUBJID, ~TRTSDT,           ~TRTEDT,           ~EOSDT,
+    "01",     ymd("2020-12-06"), ymd("2021-03-02"), ymd("2021-03-06"),
+    "02",     ymd("2021-01-16"), ymd("2021-01-20"), ymd("2021-02-03")
+  ) %>% mutate(STUDYID = "AB42")
+
+  # Define AE dataset with duplicates
+  ae <- tibble::tribble(
+    ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
+    "01",     "2021-01-03",      1, "Flu",
+    "01",     "2021-03-04",      2, "Cough",
+    "01",     "2021-01-03",      3, "Flu"
+  ) %>% mutate(
+    STUDYID = "AB42",
+    AESTDT = ymd(AESTDTC)
+  )
+
+  # Define event and censor sources
+  ttae <- event_source(
+    dataset_name = "ae",
+    date = AESTDT,
+    set_values_to = exprs(
+      EVENTDESC = "AE",
+      SRCDOM = "AE",
+      SRCVAR = "AESTDTC",
+      SRCSEQ = AESEQ
+    )
+  )
+
+  eot <- censor_source(
+    dataset_name = "adsl",
+    date = pmin(TRTEDT + days(10), EOSDT),
+    censor = 1,
+    set_values_to = exprs(
+      EVENTDESC = "END OF TRT",
+      SRCDOM = "ADSL",
+      SRCVAR = "TRTEDT"
+    )
+  )
+
+  # Run derive_param_tte and check for warning
+  expect_snapshot(
+    derive_param_tte(
+      dataset_adsl = adsl,
+      start_date = TRTSDT,
+      event_conditions = list(ttae),
+      censor_conditions = list(eot),
+      source_datasets = list(adsl = adsl, ae = ae),
+      set_values_to = exprs(PARAMCD = "TTAE"),
+      check_type = "warning"
+    )
+  )
+})
+
+## Test 15: using order for resolving ties ----
+test_that("derive_param_tte Test 15: using order for resolving ties", {
+  adsl <- tibble::tribble(
+    ~USUBJID, ~TRTSDT,           ~EOSDT,
+    "01",     ymd("2020-12-06"), ymd("2021-03-06"),
+    "02",     ymd("2021-01-16"), ymd("2021-02-03")
+  ) %>%
+    mutate(STUDYID = "AB42")
+
+  # Sort the input AE dataset in descending order by AESEQ
+  # to confirm that the order argument re-sorts it correctly.
+  ae <- tibble::tribble(
+    ~USUBJID, ~AESTDTC, ~AESEQ, ~AESER, ~AEDECOD,
+    "01", "2021-01-03", 2, "Y", "Cough",
+    "01", "2021-01-03", 1, "Y", "Flu",
+    "01", "2021-01-20", 3, "N", "Headache"
+  ) %>%
+    mutate(
+      STUDYID = "AB42",
+      AESTDT = ymd(AESTDTC)
+    ) %>%
+    arrange(desc(AESEQ)) # Intentionally sort descending to test the order argument
+
+  result <- derive_param_tte(
+    dataset_adsl = adsl,
+    start_date = TRTSDT,
+    event_conditions = list(event_source(
+      dataset_name = "ae",
+      date = AESTDT,
+      set_values_to = exprs(
+        EVENTDESC = "Serious AE",
+        SRCSEQ = AESEQ
+      ),
+      filter = AESER == "Y",
+      order = exprs(AESEQ) # Should re-sort so that AESEQ=1 (Flu) is chosen on tie
+    )),
+    censor_conditions = list(censor_source(
+      dataset_name = "adsl",
+      date = EOSDT,
+      censor = 1,
+      set_values_to = exprs(EVENTDESC = "End of Study")
+    )),
+    set_values_to = exprs(
+      PARAMCD = "TTSAE",
+      PARAM = "Time to First Serious AE"
+    ),
+    source_datasets = list(adsl = adsl, ae = ae)
+  )
+
+  # Check that for USUBJID = "01", the first serious AE selected is the one with AESEQ = 1 (Flu),
+  # despite the input AE data initially being arranged to show AESEQ=2 (Cough) first.
+  selected_seq <- result %>%
+    filter(USUBJID == "01", PARAMCD == "TTSAE") %>%
+    pull(SRCSEQ)
+
+  expect_equal(selected_seq, 1, info = "The order argument should ensure AE with AESEQ=1
+  is chosen on tie.")
+})
+
+## Test 16: produces consistent results regardless of input sort order ----
+test_that("derive_param_tte Test 16: produces consistent results regardless of input sort order", {
+  # Define ADSL dataset
+  adsl <- tibble::tribble(
+    ~USUBJID, ~TRTSDT,           ~TRTEDT,           ~EOSDT,
+    "01",     ymd("2020-12-06"), ymd("2021-03-02"), ymd("2021-03-06"),
+    "02",     ymd("2021-01-16"), ymd("2021-01-20"), ymd("2021-02-03")
+  ) %>% mutate(STUDYID = "AB42")
+
+  # Define AE dataset with duplicates
+  ae <- tibble::tribble(
+    ~USUBJID, ~AESTDTC,     ~AESEQ,  ~AEDECOD,
+    "01",     "2021-01-03",      1,  "Flu",
+    "01",     "2021-03-04",      2,  "Cough",
+    "01",     "2021-01-03",      3,  "Flu"
+  ) %>% mutate(STUDYID = "AB42", AESTDT = ymd(AESTDTC))
+
+  # Define event and censor sources
+  ttae <- event_source(
+    dataset_name = "ae",
+    date = AESTDT,
+    order = exprs(AESTDT, AESEQ),
+    set_values_to = exprs(
+      EVENTDESC = "AE",
+      SRCDOM = "AE",
+      SRCVAR = "AESTDTC",
+      SRCSEQ = AESEQ # Ensure AESEQ is included here
+    )
+  )
+
+  eot <- censor_source(
+    dataset_name = "adsl",
+    date = pmin(TRTEDT + days(10), EOSDT),
+    censor = 1,
+    set_values_to = exprs(
+      EVENTDESC = "END OF TRT",
+      SRCDOM = "ADSL",
+      SRCVAR = "TRTEDT"
+    )
+  )
+
+  # Run derive_param_tte with sorted AE dataset
+  result_sorted <- derive_param_tte(
+    dataset_adsl = adsl,
+    start_date = TRTSDT,
+    event_conditions = list(ttae),
+    censor_conditions = list(eot),
+    source_datasets = list(adsl = adsl, ae = arrange(ae, AESEQ)),
+    set_values_to = exprs(PARAMCD = "TTAE"),
+    check_type = "warning"
+  )
+
+  # Run derive_param_tte with reverse-sorted AE dataset
+  result_unsorted <- derive_param_tte(
+    dataset_adsl = adsl,
+    start_date = TRTSDT,
+    event_conditions = list(ttae),
+    censor_conditions = list(eot),
+    source_datasets = list(adsl = adsl, ae = arrange(ae, desc(AESEQ))),
+    set_values_to = exprs(PARAMCD = "TTAE"),
+    check_type = "warning"
+  )
+
+  expect_equal(result_sorted, result_unsorted)
+})
 
 # list_tte_source_objects ----
-## Test 13: error is issued if package does not exist ----
-test_that("list_tte_source_objects Test 13: error is issued if package does not exist", {
+## Test 17: error is issued if package does not exist ----
+test_that("list_tte_source_objects Test 17: error is issued if package does not exist", {
   expect_snapshot(
     list_tte_source_objects(package = "tte"),
     error = TRUE
   )
 })
 
-## Test 14: expected objects produced ----
-test_that("list_tte_source_objects Test 14: expected objects produced", {
+## Test 18: expected objects produced ----
+test_that("list_tte_source_objects Test 18: expected objects produced", {
   expected_output <- tibble::tribble(
     ~object,            ~dataset_name,                                              ~filter,
     "ae_ser_event",            "adae",                 quote(TRTEMFL == "Y" & AESER == "Y"),
