@@ -30,8 +30,8 @@ test_that("Standardized text works", {
   expect_equal(
     roxygen_order_na_handling(),
     paste(
-      "For handling of `NA`s in sorting variables see",
-      "[Sort Order](../articles/generic.html#sort_order)."
+      "For handling of `NA`s in sorting variables see the \"Sort Order\" section",
+      "in `vignette(\"generic\")`."
     )
   )
 })
